pub enum Entry<'a, K, V, S> {
Occupied(OccupiedEntry<'a, K, V, S>),
Vacant(VacantEntry<'a, K, V, S>),
}Expand description
Variants
Occupied(OccupiedEntry<'a, K, V, S>)
An occupied entry.
Vacant(VacantEntry<'a, K, V, S>)
A vacant entry.
Implementations
Sourceimpl<'a, K, V, S> Entry<'a, K, V, S>
impl<'a, K, V, S> Entry<'a, K, V, S>
Sourcepub fn insert(self, value: V) -> OccupiedEntry<'a, K, V, S>where
K: Hash,
S: BuildHasher,
pub fn insert(self, value: V) -> OccupiedEntry<'a, K, V, S>where
K: Hash,
S: BuildHasher,
Sets the value of the entry, and returns an OccupiedEntry.
Examples
use hashbrown::HashMap;
let mut map: HashMap<&str, u32> = HashMap::new();
let entry = map.entry("horseyland").insert(37);
assert_eq!(entry.key(), &"horseyland");Sourcepub fn or_insert(self, default: V) -> &'a mut Vwhere
K: Hash,
S: BuildHasher,
pub fn or_insert(self, default: V) -> &'a mut Vwhere
K: Hash,
S: BuildHasher,
Ensures a value is in the entry by inserting the default if empty, and returns a mutable reference to the value in the entry.
Examples
use hashbrown::HashMap;
let mut map: HashMap<&str, u32> = HashMap::new();
map.entry("poneyland").or_insert(3);
assert_eq!(map["poneyland"], 3);
*map.entry("poneyland").or_insert(10) *= 2;
assert_eq!(map["poneyland"], 6);Sourcepub fn or_insert_with<F: FnOnce() -> V>(self, default: F) -> &'a mut Vwhere
K: Hash,
S: BuildHasher,
pub fn or_insert_with<F: FnOnce() -> V>(self, default: F) -> &'a mut Vwhere
K: Hash,
S: BuildHasher,
Ensures a value is in the entry by inserting the result of the default function if empty, and returns a mutable reference to the value in the entry.
Examples
use hashbrown::HashMap;
let mut map: HashMap<&str, String> = HashMap::new();
let s = "hoho".to_string();
map.entry("poneyland").or_insert_with(|| s);
assert_eq!(map["poneyland"], "hoho".to_string());Sourcepub fn key(&self) -> &K
pub fn key(&self) -> &K
Returns a reference to this entry’s key.
Examples
use hashbrown::HashMap;
let mut map: HashMap<&str, u32> = HashMap::new();
assert_eq!(map.entry("poneyland").key(), &"poneyland");Sourcepub fn and_modify<F>(self, f: F) -> Self
pub fn and_modify<F>(self, f: F) -> Self
Provides in-place mutable access to an occupied entry before any potential inserts into the map.
Examples
use hashbrown::HashMap;
let mut map: HashMap<&str, u32> = HashMap::new();
map.entry("poneyland")
.and_modify(|e| { *e += 1 })
.or_insert(42);
assert_eq!(map["poneyland"], 42);
map.entry("poneyland")
.and_modify(|e| { *e += 1 })
.or_insert(42);
assert_eq!(map["poneyland"], 43);Sourceimpl<'a, K, V: Default, S> Entry<'a, K, V, S>
impl<'a, K, V: Default, S> Entry<'a, K, V, S>
Sourcepub fn or_default(self) -> &'a mut Vwhere
K: Hash,
S: BuildHasher,
pub fn or_default(self) -> &'a mut Vwhere
K: Hash,
S: BuildHasher,
Ensures a value is in the entry by inserting the default value if empty, and returns a mutable reference to the value in the entry.
Examples
use hashbrown::HashMap;
let mut map: HashMap<&str, Option<u32>> = HashMap::new();
map.entry("poneyland").or_default();
assert_eq!(map["poneyland"], None);Trait Implementations